if ~isempty(findobj('Name','Direct Adaptive Model Reference Control'))
   errormes('Is_mr')
   return
end
if ~isempty(findobj('Name','The sign of the high frequency gain is known.'))
   errormes('Is_ucI')
   return
end
if ~isempty(findobj('Name','The sign of the high frequency gain is unknown.'))
   errormes('Is_ucII')
   return
end

if ~isempty(findobj('Name','Adaptive Pole Assignment'))
   figure(findobj('Name','Adaptive Pole Assignment'))
   return
end

clear
handles = findobj('UserData','Figure');
close(handles)
handles = findobj('Name','Introduced parameters gallery');
close(handles)
handles = findobj('Name','Calculated variables gallery');
close(handles)


screen=get(0,'ScreenSize');
fig=figure('MenuBar','none','numberTitle','off',...
        'Position',[screen(3)/2-250 screen(4)/2-100 550 200],'Resize','off',...
        'Name','Adaptive Pole Assignment','NextPlot','new');


one=uimenu(fig,'Label','File','UserData','main');
uimenu(one,'Label','Load','Callback','load_pp','Enable','on');
uimenu(one,'Label','Save','Callback','save_pp','Enable','on');
uimenu(one,'Separator','on');
uimenu(one,'Label','Exit','Callback',...
           ['handles = findobj(''UserData'',''Figure'');close(handles),',...
            'close(gcf),clear,',...
            'if ~isempty(findobj(''Name'',''Introduced parameters gallery'')),',...
            '  close(findobj(''Name'',''Introduced parameters gallery'')),',...
            'end,',...
            'if ~isempty(findobj(''Name'',''Calculated variables gallery'')),',...
            '  close(findobj(''Name'',''Calculated variables gallery'')),',...
            'end']);

two = uimenu(fig,'Label','Adaptive system parameters','UserData','main');
  uimenu(two,'Label','Unknown system','Callback','sys_pp');
  two_two=uimenu(two,'Label','Initial values','Enable','off');
    uimenu(two_two,'Label','Initial estimates','Callback',...
                           'set_est(init_est,n)','Enable','off')
    uimenu(two_two,'Label','An initial state of the system','Callback',...
                           'set_st(init_st,n)','Enable','off')
  uimenu(two,'Label','Filter (optional)','Enable','off','Callback',...
                           'set_fil(filter_polynomial,rho,n)');
  uimenu(two,'Label','Closed-loop characteristic polynomial','Enable','off',...
          'CallBack','des_poly(desired_polynomial,filter_polynomial,n)');

three = uimenu(fig,'Label','Identification algorithm','UserData','main');
  three_one=uimenu(three,'Label','Recursive Least Square','Enable','off');
     uimenu(three_one,'Label','P(0) - the identity matrix','CallBack',...
                      'id=1;set_rls;clear id;');
     uimenu(three_one,'Label','P(0) - from a MAT-file','CallBack',...
                      '[RLS_par,ready]=load_p0(RLS_par,2*n,ready);check_pp;');
     uimenu(three_one,'Label','P(0) - defined by a user','CallBack',...
                      'id=0;set_rls;clear id;');
  uimenu(three,'Label','Normalized Least Mean Square','Callback',...
                       'set_nlms(NLMS_par)')

%   uimenu(three,'Label','Least Mean Square - disabled','Callback',...
%                       'set_lms(LMS_par)','Enable','off')

  uimenu(three,'Separator','on');
  uimenu(three,'Label','Dead-zone threshold','Callback','thresho','Checked','on')

  
five = uimenu(fig,'Label','Graphics','UserData','main');
     uimenu(five,'Label','Cascade','Callback','cascade(casc)')
     uimenu(five,'Label','Tile','CallBack','tile(window)')  
     uimenu(five,'Label','Combination','Callback','combi_pp(combination)')
     uimenu(five,'Label','Phase portraits','Callback','phase_pp(phases,n)','Enable','off')  

six = uimenu(fig,'Label','Simulation','UserData','main');
   uimenu(six,'Label','Number of iterations','Callback',...
                      'iter(number_of_iter)','Enable','off');
   uimenu(six,'Separator','on');
   six_two=uimenu(six,'Label','Start simulation','Enable','off');
     uimenu(six_two,'Label','with RLS algorithm','Enable','off','Callback',...
                            'string=''rls_sim'';calls;clear string;')
     uimenu(six_two,'Label','with NLMS algorithm','Enable','off','Callback',...
                            'string=''nlms_sim'';calls;clear string;')
%     uimenu(six_two,'Label','with LMS algorithm','Enable','off','Callback',...
%                            'string=''lms_sim'';calls;clear string;')

seven = uimenu(fig,'Label','Gallery','UserData','main');
   uimenu(seven,'Label','Introduced parameters','CallBack','show_pp');
   uimenu(seven,'Label','Variables values','Enable','off','CallBack',...
                        'var_pp(y,y_pred,u,e,est_error,da_in_ratio)');

han(1) = text(-0.1,0.8,'Adaptive system parameters: not set');
han(2) = text(-0.1,0.6,'Identification algorithm: not set');
han(3) = text(-0.1,0.4,'Graphics: not set');
han(4) = text(-0.1,0.2,'Simulation: not set');
set(han,'HorizontalAlignment','left','FontSize',10,'Color',[0.9 0.9 0.9]);
axis off


clear

% Initial values

n = []; % the system order
number_of_iter = [];
Sys = [];        % Sys = [-a(n-1) ... -a(0) b(n-1) ... b(0)]'
init_est = [];   
    % init_est = [-a_est(n-1) ... -a_est(0) b_est(n-1) ... b_est(0)]'
init_st = [];

filter_polynomial = [];
rho = [];

desired_polynomial = [];

RLS_par = [];
NLMS_par = [];
LMS_par = [];
threshold = [10^(-6)];

ready = [0 0 0 0 0 0 0 0]; 
   %[ unknown_system filter desired_poly identification_algorithm
   % initial_estimate initial_state number_of_iteration graphics ]

casc = [0 0 0 0 0 0 0 0];
       %[y y_pred u e est_error da_in_ratio a_est b_est]
combination = zeros(5,6);
window = zeros(10,6);
phases = zeros(3,2);

Identity = 'Pole Placement';	