function [u,h,deter] = ctrl_pp (theta,psi,desired_polynomial)
%       [u,h] = CTRL_PP(ESTIMATE,STATE,DESIRED_POLY) calculates input u and h
%       of the SISO system :
%               x(k+1) = Ax(k) +bu(k)
%       at time k , using Ackermann's formula .
%Where :
%       h = -[0 ... 1]*[b Ab ... A^(n-1)b]*polyvalm(DES_POLY,A)*M
%       ESTIMATE - estimate of the system parameters :
%       ESTIMATE = [ -a(n-1) ... -a(0) b(n-1) ... b(0) ](k)
%       STATE - state of the system
%       STATE = [ y(k) ... y(k-n+1) u(k-1) ... u(k-n+1) ]
%       DESIRED_POLY - desired characteristic polynomial
%       DESIRED_POLY - [ 1 c(n-1) ... c(0) ]

% Pawel Stadnik August 13 1996
% Copyright (C) 1996 Universiteit Twente
% All Rights Reserved


%        create M matrix
N = length(theta);
n = N/2;
a = -theta(1:n);  % a = [a(n-1) ... a(0)]'
b = theta(n+1:N); % b = [b(n-1) ... b(0)]'
if ( n ~= 1)
   a = a(2:n); b = b(2:n);
   a = flipud(a); b = flipud(b) ;
   M1 = zeros(n-1,1);M2=[];
   for index = 1:n-1
        M1 = [M1 [zeros(index-1,1) ; -a(1:n-index)]];
        M2 = [M2 [zeros(index-1,1) ; b(1:n-index)]];
   end
   M=[[M1 M2] ; [ 1 zeros(1,N-2)]];
else M = 1;
end

%       create u by Ackermann's formula

[A,b] = create_s(theta);
deter = det(ctrb(A,b));
pom = inv(ctrb(A,b));
f = -pom(n,:)*polyvalm(desired_polynomial,A);
u = f*M*psi;

h = (f*M)';




