if ~isempty(findobj('Name','Adaptive Pole Assignment'))
   errormes('Is_pp')
   return
end
if ~isempty(findobj('Name','The sign of the high frequency gain is known.'))
   errormes('Is_ucI')
   return
end
if ~isempty(findobj('Name','The sign of the high frequency gain is unknown.'))
   errormes('Is_ucII')
   return
end

if ~isempty(findobj('Name','Direct Adaptive Model Reference Control'))
   figure(findobj('Name','Direct Adaptive Model Reference Control'))
   return
end

clear
handles = findobj('UserData','Figure');
close(handles)
handles = findobj('Name','Introduced parameters gallery');
close(handles)
handles = findobj('Name','Calculated variables gallery');
close(handles)


screen=get(0,'ScreenSize');
fig=figure('MenuBar','none','numberTitle','off',...
        'Position',[screen(3)/2-250 screen(4)/2-100 550 200],'Resize','off',...
        'Name','Direct Adaptive Model Reference Control','NextPlot','new');


one=uimenu(fig,'Label','File','UserData','main');
uimenu(one,'Label','Load','Callback','load_mr');
uimenu(one,'Label','Save','Callback','save_mr');
uimenu(one,'Separator','on');
uimenu(one,'Label','Exit','Callback',...
           ['handles = findobj(''UserData'',''Figure'');close(handles),',...
            'close(gcf),clear,',...
            'if ~isempty(findobj(''Name'',''Introduced parameters gallery'')),',...
            '  close(findobj(''Name'',''Introduced parameters gallery'')),',...
            'end,',...
            'if ~isempty(findobj(''Name'',''Calculated variables gallery'')),',...
            '  close(findobj(''Name'',''Calculated variables gallery'')),',...
            'end']);

two = uimenu(fig,'Label','Adaptive system parameters','UserData','main');
  uimenu(two,'Label','Unknown system','Callback','sys_mr');
  two_two=uimenu(two,'Label','Initial values','Enable','off');
     uimenu(two_two,'Label','Initial estimates of the controller parameters',...
          'Callback','mr_est(init_est,n)')
     uimenu(two_two,'Label','An initial state of the system','Callback','set_st(init_st,n)')
  two_three=uimenu(two,'Label','Reference model','Enable','off');
  uimenu(two_three,'Label','Reference model polynomial',...
                   'Callback','mr_poly(E_polynomial,n_r)');
  t_t_f=uimenu(two_three,'Label','Reference signal');
     uimenu(t_t_f,'Label','Constant','Callback','mr_signa(1,which_signal,signal_par)')
     uimenu(t_t_f,'Label','Saw','Callback','mr_signa(5,which_signal,signal_par)')
     uimenu(t_t_f,'Label','Harmonic','Callback','mr_signa(3,which_signal,signal_par)')
     uimenu(t_t_f,'Label','White noise','Callback','mr_signa(2,which_signal,signal_par)')
     uimenu(t_t_f,'Label','Random walk','Callback','mr_signa(4,which_signal,signal_par)')
  two_four=uimenu(two,'Label','Filter','Enable','off');
  uimenu(two_four,'Label','Polynomial H','Callback','mr_fi_po(H_polynomial,n)');
  uimenu(two_four,'Label','Initial state','Callback','mr_fi_st(init_X,n)');


three = uimenu(fig,'Label','Identification algorithm','UserData','main');
   three_one=uimenu(three,'Label','Recursive Least Square','Enable','off');
     uimenu(three_one,'Label','P(0) - the identity matrix',...
                      'CallBack','id=1;set_rls;clear id;');
     uimenu(three_one,'Label','P(0) - from a MAT-file','CallBack',...
         ['[RLS_par,ready]=load_p0(RLS_par,2*n+1,ready);check_mr;']);
     uimenu(three_one,'Label','P(0) - defined by a user',...
                      'CallBack','id=0;set_rls;clear id;');
   uimenu(three,'Label','Normalized Least Mean Square',...
                'Callback','set_nlms(NLMS_par)')
%   uimenu(three,'Label','Least Mean Square - disabled',...
%                'Callback','set_lms(LMS_par)','Enable','off')
%   uimenu(three,'Separator','on');
%   uimenu(three,'Label','Dead-zone threshold','Callback','thresho','Checked','on')


four = uimenu(fig,'Label','Graphics','UserData','main');
     uimenu(four,'Label','Cascade','Callback','casc_mr')
     uimenu(four,'Label','Tile','CallBack','tile_mr(window)')  
     uimenu(four,'Label','Combination','Callback','combi_mr')
     uimenu(four,'Label','Phase portraits','Callback','phase_mr(phases,n)','Enable','off')

five = uimenu(fig,'Label','Simulation','UserData','main');
   uimenu(five,'Label','Number of iterations',...
               'Callback','iter(number_of_iter)','Enable','off');
   uimenu(five,'Separator','on');
   five_two=uimenu(five,'Label','Start simulation','Enable','off');
   uimenu(five_two,'Label','with RLS algorithm','Enable','off',...
                   'Callback','string=''rls_sim'';calls_mr;clear string;')
   uimenu(five_two,'Label','with NLMS algorithm','Enable','off',...
                   'Callback','string=''nlms_sim'';calls_mr;clear string;')
%   uimenu(five_two,'Label','with LMS algorithm','Enable','off')

six = uimenu(fig,'Label','Gallery','UserData','main');
   uimenu(six,'Label','Introduced parameters','CallBack','show_mr');
   uimenu(six,'Label','Variables values','Enable','off',...
          'CallBack','var_mr(y,y_r,u,model_error,r,da_in_ratio,rs_ou_ratio)');

han(1) = text(-0.1,0.8,'Adaptive system parameters: not set');
han(2) = text(-0.1,0.6,'Identification algorithm: not set');
han(3) = text(-0.1,0.4,'Graphics: not set');
han(4) = text(-0.1,0.2,'Simulation: not set');
set(han,'HorizontalAlignment','left','FontSize',10,'Color',[0.9 0.9 0.9]);
axis off


clear

% Initial values

n = []; % the system order
n_r = [];
number_of_iter = [];
Sys = [];        % Sys = [-a(n-1) ... -a(0) b(n-1) ... b(0)]'
bm_bar = [];
init_est = [];   
    % init_est = [-a_est(n-1) ... -a_est(0) b_est(n-1) ... b_est(0)]'
init_st = [];

H_polynomial = [];
init_X = [];

E_polynomial = [];
which_signal = 0; signal_par = [];

RLS_par = [];
NLMS_par = [];
LMS_par = [];
threshold = [10^(-6)];

ready = [0 0 0 0 0 0 0 0 0 0]; 
   %[ unknown_system H_poly init_X identification_algorithm E_poly 
   % ref_signal initial_estimate initial_state number_of_iteration graphics ]

casc = [0 0 0 0 0 0 0 0 0 0];
       %[y y_r u model_error r da_in_ratio rs_ou_ratio c_u_est c_y_est c_r_est]
combination = zeros(5,7);
window = zeros(10,7);
phases = zeros(3,2);

Identity = 'Model Reference';	

