function [new_theta , new_P] = est_rls (theta,phi,e,P)
%[NEW_ESTIMATE,NEW_P] = EST_RLS(PREVIOUS_ESTIMATE,phi,e,P)
%This function calculates new estimate of the system parameters and new
% matrix P on basis previous estimate , vector phi , error e and the matrix P ,
% using Recursive Least Squares identification algorithm .
% Where : NEW_ESTIMATE = [ -a(n-1) ... -a(0) b(n-1) ... b(0)]'(k+1) ,
%         NEW_P - the matrix P at time k+1,
%         PREVIOUS_ESTIMATE = [ - a(n-1) ... -a(0) b(n-1) ... b(0)]'(k) ,
%         phi = [y(k) ... y(k-n+1) u(k) ... u(k-n+1)]' ,
%         e - error at time k ,
%         P - the matrix P at time k.

% Pawel Stadnik August 12 1996
% Copyright (C) 1996 Universiteit Twente
% All Rights Reserved

new_theta = theta + (( P * phi )/(1 + phi'*P*phi))*e;

new_P = P - (( P*phi*phi'*P ) / (1+phi'*P*phi));
