function [y,y_est,u,e,est_error,da_in_ratio] = sim_ppf (Sys,desired_poly,filter_poly,init_est,init_st,k,...
                        threshold,rho,matrix,casc,window,many_plots,phases)
%
%
%

% Pawel Stadnik August 23 1996
% Copyright (C) 1996 Universiteit Twente
% All Rights Reserved

%       init_est = vector theta
%       init_st = vector psi
%       all vectors of the system parameters are vertical

% init_est =  [ -a(n-1) ... -a(0) b(n-1) ... b(0) ]'(0) initial estimate
% init_st = [ y(0) ... y(n-1) u(-1) ... u(n-1) ]' initial state
% Sys = [ -a(n-1) ... -a(0) b(n-1) ... b(0) ]' parameters of true system
% desired_poly = [ 1 c(n-1) ... c(0) ]

disp(blanks(5)');
disp('                           CALCULATIONS')

screen=get(0,'ScreenSize');
fig=figure('MenuBar','none','NumberTitle','off','Resize','off','UserData','Figure',...
        'Position',[screen(3)/2-200 screen(4)/2-100 400 200]);axis off
handle=text(0.5,0.5,'The simulation is in progress');
set(handle,'HorizontalAlignment','center','FontSize',18,'Color',[1 1 0])
pause(1)


N = length(Sys);n = N/2;
psi = init_st;
theta = [ init_est  zeros(N,k-1)]; % matrix  (N x k)
u = zeros(1,k)';                   % input
y = zeros(1,k)';y(1) = psi(1);     % output
e = zeros(1,k)';                   % error
y_est = zeros(1,k)';               % predicted output
z = ones(N,k);
est_error = zeros(1,k )';          % estimate error
da_in_ratio = zeros(1,k)';         % desired/actual input ratio
c = [zeros(1,n-1) 1];              % c = [ 0 0 ... 0 1]
q0=[c';zeros(n,1)];
E = ones(1,k)';

for index=2:k
  E(index) = rho*E(index-1);
end

% create [b(0) l(0)] form initial estimate

 b_est = flipud(theta(n+1:N,1));
 l_est = flipud(filter_poly(2:n+1))+flipud(theta(1:n,1));
 bl = [[b_est ; l_est] zeros(N,k-1)];

% create [b l] from true system

 b_true = flipud(Sys(n+1:N));
 l_true = flipud(filter_poly(2:n+1))+flipud(Sys(1:n,1));

% create filter matrix

 F = [[zeros(1,n-1) ; eye(n-1)] -flipud(filter_poly(2:n+1))];

% create P0 matrix from true system

P0 = [[F' zeros(n)] ;[c'*b_true' (F+l_true*c)']];
pom = inv(ctrb(P0,q0));
f_P0_q0 = -pom(N,:)*polyvalm(desired_poly,P0);
y_est(1) = [b_est' l_est']*z(:,1);
e(1) = y(1) - y_est(1);

P = [[F' zeros(n)] ; [c'*b_est' (F+l_est*c)']];
% control law
pom = inv(ctrb(P,q0));
u(1) = -pom(N,:)*polyvalm(desired_poly,P)*z(:,1);

est_error = norm(theta(:,1)-Sys);
da_in_ratio(1) = f_P0_q0*z(:,1)/u(1);

phi = [psi(1:n); u(1) ; psi(n+1:N-1)];

ll = fix(k/10);counter=1;
symb = 'X';

for index=2:k
   if ( index == counter*ll )
        disp(sprintf('%d %%',10*counter))
        counter = counter+1;
   end
% create new estimate

   if ( norm(z(:,index)) <= threshold )
        bl(:,index) = bl(:,index-1);
   else
      if ( e(index-1) > E(index-1) )
         if ( size(matrix) == [N N] )
            [bl(:,index),matrix] = est_rls(bl(:,index-1),...
                z(:,index-1),e(index-1)-E(index-1),matrix);
         elseif ( size(matrix) == [1 2] )
            bl(:,index) = est_nlms(bl(:,index-1),...
                z(:,index-1),e(index-1)-E(index-1),matrix(1),matrix(2));
         elseif ( size(matrix) == [1 1] )
            bl(:,index) = est_lms(bl(:,index-1),...
                z(:,index-1),e(index-1)-E(index-1),matrix);
         end
      elseif( e(index-1) < -E(index-1) )
         if ( size(matrix) == [N N] )
            [bl(:,index),matrix] = est_rls(bl(:,index-1),...
                z(:,index-1),e(index-1)+E(index-1),matrix);
         elseif ( size(matrix) == [1 2] )
            bl(:,index) = est_nlms(bl(:,index-1),...
                z(:,index-1),e(index-1)+E(index-1),matrix(1),matrix(2));
         elseif ( size(matrix) == [1 1] )
            bl(:,index) = est_lms(bl(:,index-1),...
                z(:,index-1),e(index-1)+E(index-1),matrix);
         end
      else
         bl(:,index) = bl(:,index-1);
      end
   end
% create new [b l] vector

   b_est = bl(1:n,index);
   l_est = bl(n+1:N,index);

   theta(:,index) = ...
        [flipud(l_est)-filter_poly(2:n+1) ; flipud(b_est) ];

   z(:,index) = [[F' zeros(n)] ; [zeros(n) F']]*z(:,index-1) ...
                 + [c' ;zeros(n,1)]*u(index-1)...
                 + [zeros(n,1) ; c']*y(index-1);

   y_est(index) = [b_est' l_est']*z(:,index);
   y(index) = Sys'*phi;
   e(index) = y(index) - y_est(index);

   P = [[F' zeros(n)] ; [c'*b_est' (F+l_est*c)']];

   % control law
   pom = inv(ctrb(P,q0));
   u(index) = -pom(N,:)*polyvalm(desired_poly,P)*z(:,index);
   est_error(index) = norm(theta(:,index)-Sys);
   da_in_ratio(index) = f_P0_q0*z(:,index)/u(index);



   if ( n == 1 )
        psi = y(index);
   else
        psi = [y(index);psi(1:n-1);u(index-1);psi(n+1:N-2)];
   end

   phi = [psi(1:n); u(index); psi(n+1:N-1)];
end


clc

if ~isempty(fig)
  close(fig)
end
clear fig

plot_pp (y,y_est,u,e,est_error,da_in_ratio,Sys,theta,k,casc,window,many_plots,phases);

if ~all(finite(y))|~all(finite(u))|~all(finite(e))|~all(finite(y_est))
   errormes('NAN')
end

