if ~isempty(findobj('Name','Direct Adaptive Model Reference Control'))
   errormes('Is_mr')
   return
end
if ~isempty(findobj('Name','Adaptive Pole Assignment'))
   errormes('Is_pp')
   return
end
if ~isempty(findobj('Name','The sign of the high frequency gain is known.'))
   errormes('Is_ucI')
   return
end

if ~isempty(findobj('Name','The sign of the high frequency gain is unknown.'))
   figure(findobj('Name','The sign of the high frequency gain is unknown.'))
   return
end

clear
handles = findobj('UserData','Figure');
close(handles)
handles = findobj('Name','Introduced parameters gallery');
close(handles)
handles = findobj('Name','Calculated variables gallery');
close(handles)

screen=get(0,'ScreenSize');
fig=figure('MenuBar','none','numberTitle','off',...
        'Position',[screen(3)/2-200 screen(4)/2-100 400 200],'Resize','off',...
        'Name','The sign of the high frequency gain is unknown.','NextPlot','new');


one=uimenu(fig,'Label','File','UserData','main');
uimenu(one,'Label','Load','Callback','load_uc2','Enable','on');
uimenu(one,'Label','Save','Callback','save_uc2','Enable','on');
uimenu(one,'Separator','on');
uimenu(one,'Label','Exit','Callback',...
           ['handles = findobj(''UserData'',''Figure'');close(handles),',...
            'close(gcf),clear,',...
            'if ~isempty(findobj(''Name'',''Introduced parameters gallery'')),',...
            '  close(findobj(''Name'',''Introduced parameters gallery'')),',...
            'end,',...
            'if ~isempty(findobj(''Name'',''Calculated variables gallery'')),',...
            '  close(findobj(''Name'',''Calculated variables gallery'')),',...
            'end']);


two = uimenu(fig,'Label','Adaptive system parameters','UserData','main');
   uimenu(two,'Label','Unknown system','CallBack','sys_uc2')
   two_two=uimenu(two,'Label','Initial values');
     uimenu(two_two,'Label','Initial state','CallBack','set_y0')
     uimenu(two_two,'Label','Initial value of k','CallBack','set_k02')
   two_two=uimenu(two,'Label','Switching function');
      uimenu(two_two,'Label','sin(sqrt(1+abs(k)))',...
        'Callback',...
         ['switch_fun = ''sin(sqrt(1+abs(k)))'';',...
          'handle=findobj(''Label'',''sin(sqrt(1+abs(k)))'');',...
          'set(get(handle,''Parent''),''Checked'',''on''),',...
          'set(get(get(handle,''Parent''),''Children''),''Checked'',''off''),',...          
          'set(handle,''Checked'',''on''),clear handle,ready(6)=1;check_u2,']);
      uimenu(two_two,'Label','sin(1+abs(k))',...
        'CallBack',...
         ['switch_fun = ''sin(1+abs(k))'';',...
          'handle=findobj(''Label'',''sin(1+abs(k))'');',...
          'set(get(handle,''Parent''),''Checked'',''on''),',...
          'set(get(get(handle,''Parent''),''Children''),''Checked'',''off''),',...          
          'set(handle,''Checked'',''on''),clear handle,ready(6)=1;check_u2,']);
      uimenu(two_two,'Label','(-1).^(floor(log(k)/log(2)))',...
         'CallBack',...
          ['switch_fun = ''(-1).^(floor(log(k)/log(2)))'';',...
          'handle=findobj(''Label'',''(-1).^(floor(log(k)/log(2)))'');',...
          'set(get(handle,''Parent''),''Checked'',''on''),',...
          'set(get(get(handle,''Parent''),''Children''),''Checked'',''off''),',...          
          'set(handle,''Checked'',''on''),clear handle,ready(6)=1;check_u2,']);

three = uimenu(fig,'Label','Graphics','UserData','main');
     uimenu(three,'Label','Cascade','Callback','casc_uc2')
     uimenu(three,'Label','Tile','CallBack','tile_uc2')  
     uimenu(three,'Label','Combination','Callback','combi_uc')

call = ['screen=get(0,''ScreenSize'');',...
        'fig=figure(''MenuBar'',''none'',''NumberTitle'',''off'',''Resize'',''off'',',...
        '''Position'',[screen(3)/2-200 screen(4)/2-100 400 200],''UserData'',''Figure'');axis off,',...
        'handle=text(0.5,0.5,''The simulation is in progress'');',...
        'set(handle,''HorizontalAlignment'',''center'',''FontSize'',18,''Color'',[1 1 0]),',...
        'clear handle screen,pause(1),',...
        '[t,x]=ode23(''eq_uc2'',0,time,[y0 k0],tol);',...
        'if ~isempty(fig),close(fig),end,clear fig ,',...
        'u = -x(:,2).*x(:,1);',...
        'y = x(:,1); k = x(:,2);',...
        'plot_uc(y,u,k,switch_fun,t,casc,window,combination),',...
        'set(findobj(''Label'',''Variables values''),''Enable'',''on''),',...
        'if ~isempty(findobj(''Name'',''Calculated variables gallery'')),',...
        '  var_uc(y,u,k),',...
        'end'];

five = uimenu(fig,'Label','Simulation','UserData','main');
   uimenu(five,'Label','Length of simulation','Callback','set_time');
   uimenu(five,'Label','Desired accuracy','Checked','on','CallBack','set_tol')
   uimenu(five,'Separator','on');
   uimenu(five,'Label','Start simulation','Enable','off','CallBack',call);

seven = uimenu(fig,'Label','Gallery','UserData','main');
   uimenu(seven,'Label','Introduced parameters','CallBack','show_uc2');
   uimenu(seven,'Label','Variables values','Enable','off','CallBack','var_uc(y,u,k)');

han(1) = text(-0.1,0.7,'Adaptive system parameters: not set');
han(2) = text(-0.1,0.5,'Graphics: not set');
han(3) = text(-0.1,0.3,'Simulation: not set');
set(han,'HorizontalAlignment','left','FontSize',10,'Color',[0.9 0.9 0.9]);
axis off


clear 

% Initial values

global a b switch_fun 

a = [];
b = [];
switch_fun = [];
time = [];
y0 = [];
k0 = [];
tol = 10^(-3);

ready = [0 0 0 0 0 0];  % [System_parameters y0 k0 time graphics switching_function]
       
casc = [0 0 0 0 0];
       %[y u k phase_portrait(k,y) switching_function]
window = zeros(6,5);
combination = zeros(2,3);

Identity = 'Universal Control: case II';	